<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sl">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="mainwindow.ui" line="26"/>
        <location filename="ui_mainwindow.h" line="888"/>
        <source>User Manager</source>
        <translation>Upravljalnik uporabnikov</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="62"/>
        <location filename="ui_mainwindow.h" line="945"/>
        <source>Administration</source>
        <translation>Administracija</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="65"/>
        <location filename="ui_mainwindow.h" line="946"/>
        <source>Add a new user</source>
        <translation>Dodaj novega uporabnika</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="105"/>
        <location filename="ui_mainwindow.h" line="889"/>
        <source>Add User Account</source>
        <translation>Dodaj uporabniški račun</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="132"/>
        <location filename="ui_mainwindow.h" line="891"/>
        <source>Reenter password for new user</source>
        <translation>Ponovno vnesi geslo za novega uporabnika</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="141"/>
        <location filename="ui_mainwindow.h" line="894"/>
        <source>confirm password</source>
        <translation>potrdi geslo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="157"/>
        <location filename="mainwindow.ui" line="1163"/>
        <location filename="ui_mainwindow.h" line="896"/>
        <location filename="ui_mainwindow.h" line="1036"/>
        <source>Username of new user</source>
        <translation>Uporabniško ime novega uporabnika</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="160"/>
        <location filename="ui_mainwindow.h" line="898"/>
        <source>User login name:</source>
        <translation>Uporabniško ime za prijavo:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="176"/>
        <location filename="mainwindow.ui" line="443"/>
        <location filename="mainwindow.ui" line="1182"/>
        <location filename="ui_mainwindow.h" line="900"/>
        <location filename="ui_mainwindow.h" line="934"/>
        <location filename="ui_mainwindow.h" line="1040"/>
        <source>Enter username of new user</source>
        <translation>Vnesite uporabniško ime novega uporabnika</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="182"/>
        <location filename="mainwindow.ui" line="449"/>
        <location filename="ui_mainwindow.h" line="903"/>
        <location filename="ui_mainwindow.h" line="937"/>
        <source>username</source>
        <translation>uporabniško ime</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="198"/>
        <location filename="mainwindow.ui" line="242"/>
        <location filename="ui_mainwindow.h" line="905"/>
        <location filename="ui_mainwindow.h" line="914"/>
        <source>Password for new user</source>
        <translation>Geslo novega uporabnika</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="201"/>
        <location filename="ui_mainwindow.h" line="907"/>
        <source>User password:</source>
        <translation>Geslo uporabnika:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="217"/>
        <location filename="ui_mainwindow.h" line="909"/>
        <source>Enter password for new user</source>
        <translation>Vnesite geslo za novega uporabnika</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="226"/>
        <location filename="ui_mainwindow.h" line="912"/>
        <source>password</source>
        <translation>geslo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="245"/>
        <location filename="ui_mainwindow.h" line="916"/>
        <source>Confirm user password:</source>
        <translation>Potrdi geslo uporabnika:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="280"/>
        <location filename="ui_mainwindow.h" line="917"/>
        <source>Delete User Account</source>
        <translation>Izbriši uporabniški računa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="323"/>
        <location filename="ui_mainwindow.h" line="919"/>
        <source>Select user</source>
        <translation>Izberi uporabnika</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="339"/>
        <location filename="mainwindow.ui" line="1260"/>
        <location filename="mainwindow.ui" line="1273"/>
        <location filename="mainwindow.ui" line="1400"/>
        <location filename="mainwindow.ui" line="1425"/>
        <location filename="ui_mainwindow.h" line="923"/>
        <location filename="ui_mainwindow.h" line="1046"/>
        <location filename="ui_mainwindow.h" line="1049"/>
        <location filename="ui_mainwindow.h" line="1055"/>
        <location filename="ui_mainwindow.h" line="1059"/>
        <source>Select user to delete</source>
        <translation>Izberi uporabnika, ki ga želite izbrisati</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="348"/>
        <location filename="ui_mainwindow.h" line="925"/>
        <source>User to delete:</source>
        <translation>Uporabnik za izbris</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="364"/>
        <location filename="ui_mainwindow.h" line="927"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Izbriši tudi domači direktorij uporabnika</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="367"/>
        <location filename="ui_mainwindow.h" line="929"/>
        <source>Delete user home directory</source>
        <translation>Izbriši domači direktorij uporabnika</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="380"/>
        <location filename="ui_mainwindow.h" line="930"/>
        <source>Rename User Account</source>
        <translation>Premimenuje uporabniški račun</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="392"/>
        <location filename="mainwindow.ui" line="522"/>
        <location filename="ui_mainwindow.h" line="931"/>
        <location filename="ui_mainwindow.h" line="943"/>
        <source>Select user to modify:</source>
        <translation>Izberite uporabnika za spreminjanje:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="427"/>
        <location filename="ui_mainwindow.h" line="932"/>
        <source>New user name:</source>
        <translation>Novo uporabniško ime:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="462"/>
        <location filename="ui_mainwindow.h" line="938"/>
        <source>Change User Password</source>
        <translation>Spremeni geslo uproabnika:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="477"/>
        <location filename="ui_mainwindow.h" line="940"/>
        <source>new password</source>
        <translation>novo geslo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="493"/>
        <location filename="ui_mainwindow.h" line="941"/>
        <source>Confirm new password:</source>
        <translation>Potrdi novo geslo:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="506"/>
        <location filename="ui_mainwindow.h" line="942"/>
        <source>confirm new password</source>
        <translation>potrdi novo geslo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="538"/>
        <location filename="ui_mainwindow.h" line="944"/>
        <source>New user password:</source>
        <translation>Novo geslo uporabnika:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="572"/>
        <location filename="ui_mainwindow.h" line="979"/>
        <source>Options</source>
        <translation>Opcije</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="575"/>
        <location filename="ui_mainwindow.h" line="980"/>
        <source>Repair a user configuration</source>
        <translation>Popravi uporabnikovo konfiguracijo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="609"/>
        <location filename="mainwindow.ui" line="1325"/>
        <location filename="ui_mainwindow.h" line="947"/>
        <location filename="ui_mainwindow.h" line="1053"/>
        <source>Modify User Account</source>
        <translation>Prilagodi uporabniški račun</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="621"/>
        <location filename="mainwindow.ui" line="637"/>
        <location filename="ui_mainwindow.h" line="949"/>
        <location filename="ui_mainwindow.h" line="953"/>
        <source>Select user to repair</source>
        <translation>Izberi uporabnika za popravilo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="624"/>
        <location filename="mainwindow.ui" line="1409"/>
        <location filename="ui_mainwindow.h" line="951"/>
        <location filename="ui_mainwindow.h" line="1057"/>
        <source>User to change:</source>
        <translation>Uporabnik, katerega se spreminja:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="669"/>
        <location filename="ui_mainwindow.h" line="955"/>
        <source>Restore Defaults</source>
        <translation>Obnovi privzete nastavitve</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="690"/>
        <location filename="ui_mainwindow.h" line="957"/>
        <source>Restore browser configs to antiX defaults</source>
        <translation>Obnovi konfiguracijo brskalnika na privzete nastavitve za antiX</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="696"/>
        <location filename="ui_mainwindow.h" line="962"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Mozilla (Iceweasel ali Firefox) konfiguracije</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="699"/>
        <location filename="ui_mainwindow.h" line="964"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="706"/>
        <location filename="ui_mainwindow.h" line="967"/>
        <source>Restore group memberships to antiX defaults</source>
        <translation>Obnovi članstvo v skupinah na privzete nastavitve za antiX </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="712"/>
        <location filename="ui_mainwindow.h" line="972"/>
        <source>Group memberships</source>
        <translation>Članstvo v skupinah</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="715"/>
        <location filename="ui_mainwindow.h" line="974"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="725"/>
        <location filename="ui_mainwindow.h" line="976"/>
        <source>Change Autologin Settings</source>
        <translation>Spremeni nastavitve za samodejno prijavo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="731"/>
        <location filename="ui_mainwindow.h" line="977"/>
        <source>Log in automatically</source>
        <translation>Samodejna prijava</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="738"/>
        <location filename="ui_mainwindow.h" line="978"/>
        <source>Require password to log in</source>
        <translation>Zahtevaj geslo za prijavo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="753"/>
        <location filename="ui_mainwindow.h" line="1033"/>
        <source>Copy/Sync</source>
        <translation>Kopiranje/sinhronizacija</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="780"/>
        <location filename="ui_mainwindow.h" line="981"/>
        <source>Copy Between Desktops</source>
        <translation>Kopiranje med namizij</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="807"/>
        <location filename="mainwindow.ui" line="874"/>
        <location filename="ui_mainwindow.h" line="983"/>
        <location filename="ui_mainwindow.h" line="997"/>
        <source>Select desktop to copy from</source>
        <translation>Izberite namizje s katerega naj se kopira</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="820"/>
        <location filename="ui_mainwindow.h" line="986"/>
        <source>Select to only copy files</source>
        <translation>Zgolj kopiranje datotek</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="823"/>
        <location filename="ui_mainwindow.h" line="988"/>
        <source>Copy only</source>
        <translation>Zgolj kopiranje</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="839"/>
        <location filename="mainwindow.ui" line="852"/>
        <location filename="ui_mainwindow.h" line="990"/>
        <location filename="ui_mainwindow.h" line="993"/>
        <source>Select desktop to copy to</source>
        <translation>Izberi namizje na katerega naj se kopira</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="861"/>
        <location filename="ui_mainwindow.h" line="995"/>
        <source>Copy to:</source>
        <translation>Kopiraj na:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="883"/>
        <location filename="ui_mainwindow.h" line="999"/>
        <source>Copy from:</source>
        <translation>Kopiraj iz:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="896"/>
        <location filename="ui_mainwindow.h" line="1001"/>
        <source>Select to copy and then delete differences</source>
        <translation>Izberi za kopiranje in potem izbriši razlike </translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="899"/>
        <location filename="ui_mainwindow.h" line="1003"/>
        <source>Sync</source>
        <translation>Sinhronizacija</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="945"/>
        <location filename="ui_mainwindow.h" line="1006"/>
        <source>Select to copy/sync Shared</source>
        <translation>Izberite za kopiranje/sinhroniziranje virov v skupni rabi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="948"/>
        <location filename="ui_mainwindow.h" line="1008"/>
        <source>Shared folder</source>
        <translation>Skupna mapa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="961"/>
        <location filename="ui_mainwindow.h" line="1010"/>
        <source>Select to copy/sync entire home</source>
        <translation>Izberi za kopiranje ali sinhronizacijo celotne domače mape</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="964"/>
        <location filename="ui_mainwindow.h" line="1012"/>
        <source>Entire home</source>
        <translation>Celotna domača mapa</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="980"/>
        <location filename="ui_mainwindow.h" line="1014"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Izberi za kopiranje ali sinhronizacijo konfiguracije brskalnika</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="983"/>
        <location filename="ui_mainwindow.h" line="1016"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Mozilla (Iceweasel ali Firefox) konfiguracije</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="996"/>
        <location filename="ui_mainwindow.h" line="1018"/>
        <source>Select to copy/sync Documents</source>
        <translation>Izberi za kopiranje ali sinhronizacijo dokumentov</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="999"/>
        <location filename="ui_mainwindow.h" line="1020"/>
        <source>Documents folder</source>
        <translation>Mapa z dokumenti</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1006"/>
        <location filename="ui_mainwindow.h" line="1021"/>
        <source>What to copy/sync:</source>
        <translation>Kaj naj se kopira ali sinhronizira:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1022"/>
        <location filename="ui_mainwindow.h" line="1022"/>
        <source>Progress</source>
        <translation>Napredek</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1052"/>
        <location filename="mainwindow.ui" line="1068"/>
        <location filename="ui_mainwindow.h" line="1024"/>
        <location filename="ui_mainwindow.h" line="1027"/>
        <source>Status of the changes</source>
        <translation>Status sprememb</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1071"/>
        <location filename="ui_mainwindow.h" line="1029"/>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1087"/>
        <location filename="ui_mainwindow.h" line="1031"/>
        <source>Progress of the changes</source>
        <translation>Napredek sprememb</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1124"/>
        <location filename="ui_mainwindow.h" line="1052"/>
        <source>Add/Remove Groups</source>
        <translation>Dodaj/odstrani skupine</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1136"/>
        <location filename="ui_mainwindow.h" line="1034"/>
        <source>Add Group</source>
        <translation>Dodaj skupino</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1166"/>
        <location filename="ui_mainwindow.h" line="1038"/>
        <source>Group name:</source>
        <translation>Ime skupine:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1188"/>
        <location filename="ui_mainwindow.h" line="1043"/>
        <source>groupname</source>
        <translation>groupname</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1220"/>
        <location filename="ui_mainwindow.h" line="1044"/>
        <source>Delete Group</source>
        <translation>Izbriši skupino</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1282"/>
        <location filename="ui_mainwindow.h" line="1051"/>
        <source>Group to delete:</source>
        <translation>Skupina za izbris:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1313"/>
        <location filename="ui_mainwindow.h" line="1063"/>
        <source>Group Membership</source>
        <translation>Članstvo v skupini</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1432"/>
        <location filename="ui_mainwindow.h" line="1061"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Člani skupine pripadajo (spreminjajte skupine z označevanjem ustreznih polj):</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1452"/>
        <location filename="ui_mainwindow.h" line="1062"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation>*Ponovno preverite izbiro pred potrditvijo. Določanje napačnih članstev v skupinah lahko pokavri vaš sistem. Uporabite zaviheh Popravi za obnovo originalnega članstva, če ste storili napako.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1512"/>
        <location filename="ui_mainwindow.h" line="1065"/>
        <source>Apply any changes</source>
        <translation>Potrdi vse spremembe</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1515"/>
        <location filename="ui_mainwindow.h" line="1067"/>
        <source>Apply</source>
        <translation>Potrdi</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1522"/>
        <location filename="ui_mainwindow.h" line="1069"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1529"/>
        <location filename="ui_mainwindow.h" line="1072"/>
        <source>Cancel any changes then quit</source>
        <translation>Zavrzi vse spremembe in končaj</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1532"/>
        <location filename="ui_mainwindow.h" line="1074"/>
        <source>Close</source>
        <translation>Zapri</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1539"/>
        <location filename="ui_mainwindow.h" line="1076"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1580"/>
        <location filename="ui_mainwindow.h" line="1080"/>
        <source>Display help </source>
        <translation>Prikaži pomoč</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1583"/>
        <location filename="ui_mainwindow.h" line="1082"/>
        <source>Help</source>
        <translation>Pomoč</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1590"/>
        <location filename="ui_mainwindow.h" line="1084"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1597"/>
        <location filename="ui_mainwindow.h" line="1087"/>
        <source>About this application</source>
        <translation>O tem programu</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1600"/>
        <location filename="ui_mainwindow.h" line="1089"/>
        <source>About...</source>
        <translation>O programu...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="1607"/>
        <location filename="ui_mainwindow.h" line="1091"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="111"/>
        <location filename="mainwindow.cpp" line="153"/>
        <location filename="mainwindow.cpp" line="161"/>
        <location filename="mainwindow.cpp" line="174"/>
        <location filename="mainwindow.cpp" line="185"/>
        <location filename="mainwindow.cpp" line="194"/>
        <location filename="mainwindow.cpp" line="203"/>
        <location filename="mainwindow.cpp" line="631"/>
        <location filename="mainwindow.cpp" line="647"/>
        <location filename="mainwindow.cpp" line="675"/>
        <location filename="mainwindow.cpp" line="683"/>
        <location filename="mainwindow.cpp" line="814"/>
        <location filename="mainwindow.cpp" line="918"/>
        <source>none</source>
        <translation>brez</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="139"/>
        <location filename="mainwindow.cpp" line="625"/>
        <location filename="mainwindow.cpp" line="821"/>
        <location filename="mainwindow.cpp" line="829"/>
        <source>browse...</source>
        <translation>brskanje...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="212"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Uporabniška konfiguracija bo popravljena. Prosimo, zaprite vse aplikacije. Po zaključku se odjavite ali ponovno zaženite sistem. Ste prepričani, da želite pričeti s popravilom?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="231"/>
        <source>User group membership was restored.</source>
        <translation>Članstvo upoabnika v skupini je bilo obnovljeno.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="237"/>
        <source>Mozilla settings were reset.</source>
        <translation>Mozilla nastavitve so bile ponastavljene.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="246"/>
        <location filename="mainwindow.cpp" line="255"/>
        <source>Autologin options</source>
        <translation>Nastavitve za samodejno prijavo</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="247"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Samodejna prijava je izključena za račun &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="256"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Samodejna prijava je vključena za račun &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="268"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Določiti morate cilj za &apos;kopiranje v&apos;. Ne morete kopirati na namizje na katerega ste prijavljeni.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="272"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Pred kopiranjem zaprite vse ostale aplikacije. Preverite, da je cilj kopiranja dovolj velik za datoteke, ki jih kopirate. Kopiranje med namizji lahko prepiše ali izbiriše datoteke na viljnem namizju. Ali ste prepričani, da želite nadaljevati?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="295"/>
        <source>Synchronizing desktop...</source>
        <translation>Sinhronizacija namizij ...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="297"/>
        <source>Copying desktop...</source>
        <translation>Kopiranje namizij ...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="324"/>
        <location filename="mainwindow.cpp" line="499"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Uporabniško ime mora imeti dolžino vsaj dveh znakov. Izberite daljše ime za nadaljevanje.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="328"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Uporabniško ime ne more vsebovati posebnih znakov ali presledkov.
Prosimo, izberite drugo ime pred nadaljevanjem.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="336"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Oprostite, to ime se že uporablja. Izberite drugo ime.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="340"/>
        <location filename="mainwindow.cpp" line="372"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Gesli se ne ujemata. Poskusite znova.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="345"/>
        <location filename="mainwindow.cpp" line="377"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Gesli morata imeti dolžino vsaj dveh znakov. Vnesite daljše geslo.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="361"/>
        <source>The user was added ok.</source>
        <translation>Uporabnik je bil uspešno dodan.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="364"/>
        <source>Failed to add the user.</source>
        <translation>Neuspešno dodajanje uporabnika.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="390"/>
        <source>Password successfully changed.</source>
        <translation>Geslo je bilo uspešno spremenjeno.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="393"/>
        <source>Failed to change password.</source>
        <translation>Neuspel poskus spremembe gesla.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="399"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Te akcije ni mogoče razveljaviti. Ali ste prepričani, da želite izbrisati uporabnika %1?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="411"/>
        <source>The user has been deleted.</source>
        <translation>Uporabnik je bil izbrisan.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="413"/>
        <source>Failed to delete the user.</source>
        <translation>Uporabnika ni bilo mogoče izbrisati.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="426"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Ime skupine mora imeti dolžino vsaj dveh znakov. Izberite daljše ime za nadaljevanje.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="430"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Ime skupine mora vsebovati le majhne znake in
mora biti brez posebnih znakov ali presledkov.
Izberite drugo ime.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="439"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Oprostite, to ime skupine  je že v rabi. Prosimo, izberite drugo ime.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="445"/>
        <source>The system group was added ok.</source>
        <translation>Skupina je bila uspešno dodana.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="447"/>
        <source>Failed to add the system group.</source>
        <translation>Neuspešno dodajanje skupine.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="449"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Tega ni mogoče razveljaviti. Ali ste prepričani, da želite izbrisati skupino %1?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="455"/>
        <source>The group has been deleted.</source>
        <translation>Skupina je bila izbrisana.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="457"/>
        <source>Failed to delete the group.</source>
        <translation>Skupine ni bilo mogoče izbrisati.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="476"/>
        <source>The changes have been applied.</source>
        <translation>Spremembe so bile uspešno izvedene.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="478"/>
        <source>Failed to apply group changes</source>
        <translation>Potrjevanje sprememb skupin ni bilo uspešno</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="490"/>
        <source>The selected user name is currently in use.</source>
        <translation>Izbrano uporabniško ime se že uporablja.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="491"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Za preimenovanje tega uporabnika se odjavite in ponovno prijavite z drugim uporabniškim računom.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="503"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Uporabniško ime mora vsebovati le majhne znake in
mora biti brez posebnih znakov ali presledkov.
Izberite drugo ime.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="512"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Oprostite, to ime je na vašem sistemu že v rabi. Izberite drugo ime.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="520"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Neuspešno preimenovanje uporabnika. Prepričajte se, da uporabnik ni prijavljen. Morda bo potreben ponoven zagon.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="539"/>
        <source>The user was renamed.</source>
        <translation>Uporabnik je bil preimenovan.</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="552"/>
        <location filename="mainwindow.cpp" line="579"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Sinhronizacija namizja... uspela!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="554"/>
        <location filename="mainwindow.cpp" line="581"/>
        <source>Copying desktop...ok</source>
        <translation>Kopiranje namizja... uspelo!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="584"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Sinhronizacija namizja... neuspešno!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="586"/>
        <source>Copying desktop...failed</source>
        <translation>Kopiranje namizia... neuspešno!</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="602"/>
        <source>Confirmation</source>
        <translation>Potrditev</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="603"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation>Proces ni bil zaključen. Želite vseeno končati program?</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="778"/>
        <source>About %1</source>
        <translation>O %1</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="779"/>
        <source>Version: </source>
        <translation>Različica:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="780"/>
        <source>Simple user configuration for antiX Linux</source>
        <translation>Preprosto konfiguriranje uporabniških računov za antiX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="782"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="783"/>
        <source>%1 License</source>
        <translation>%1 licenca</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="797"/>
        <source>%1 Help</source>
        <translation>%1 pomoč</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="822"/>
        <source>Select folder to copy to</source>
        <translation>Izberite ciljno mapo za kopiranje</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="about.cpp" line="32"/>
        <source>License</source>
        <translation>Licenca</translation>
    </message>
    <message>
        <location filename="about.cpp" line="33"/>
        <location filename="about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Dnevnik sprememb</translation>
    </message>
    <message>
        <location filename="about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Prekliči</translation>
    </message>
    <message>
        <location filename="about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Zapri</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="45"/>
        <source>Error</source>
        <translation>Napaka</translation>
    </message>
    <message>
        <location filename="main.cpp" line="46"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Prijavljeni ste kot korenski (root) uporabnik. Izpišite se in se ponovno prijavite kot običajen uporabnik, če želite uporabljati ta program.</translation>
    </message>
</context>
</TS>